@@ -53,14 +53,18 @@ class Composer(ABC):
 
     def __init__(self, metrics: Optional[Callable], composer_requirements: ComposerRequirements,
                  optimiser_parameters: Any = None, initial_chain: Optional[Chain] = None,
-                 log: Log = default_log(__name__)):
+                 log: Log = None):
         self.history = None
-        self.log = log
         self.metrics = metrics
         self.composer_requirements = composer_requirements
         self.optimiser_parameters = optimiser_parameters
         self.initial_chain = initial_chain
 
+        if not log:
+            self.log = default_log(__name__)
+        else:
+            self.log = log
+
     @abstractmethod
     def compose_chain(self, data: InputData,
                       is_visualise: bool = False) -> Chain:
